@@ -31,3 +31,16 @@
 ## usethis namespace: start
 ## usethis namespace: end
 NULL
+
+# from tune
+# nocov start
+
+is_cran_check <- function() {
+  if (identical(Sys.getenv("NOT_CRAN"), "true")) {
+    FALSE
+  } else {
+    Sys.getenv("_R_CHECK_PACKAGE_NAME_", "") != ""
+  }
+}
+
+# nocov end
