@@ -5,9 +5,7 @@ test_that("lm + axe_call() works", {
 })
 
 test_that("lm + offset + axe_call() works", {
-  example <- lm(Sepal.Length ~ Sepal.Width,
-                offset = rep(10, 150),
-                data = iris)
+  example <- lm(Sepal.Length ~ Sepal.Width, offset = rep(10, 150), data = iris)
   x <- axe_call(example)
   expect_equal(x$call$offset, example$call$offset)
 })
@@ -36,8 +34,9 @@ test_that("lm + butcher() works", {
 test_that("lm + predict() works", {
   lm_fit <- lm(mpg ~ ., data = mtcars)
   x <- butcher(lm_fit)
-  expect_equal(predict(x)[1],predict(lm_fit)[1])
-  set.seed(0); w <- runif(nrow(trees), 1, 2)
+  expect_equal(predict(x)[1], predict(lm_fit)[1])
+  set.seed(0)
+  w <- runif(nrow(trees), 1, 2)
   X <- model.matrix(~ Girth + Volume, trees)
   y <- trees$Height
   fit_by_wls <- lm(y ~ X - 1, weights = w)
