@@ -6,11 +6,12 @@ test_that("Generate expected UI messages", {
   obj_size_diff <- lobstr::obj_size(big) - lobstr::obj_size(small)
   obj_size_diff <- format(obj_size_diff, big.mark = ",", scientific = FALSE)
 
-  expect_snapshot({
-    assess_object(big, small)
-    assess_object(small, small)
-    assess_object(small, big)
-  },
-  transform = function(x) gsub(obj_size_diff, "<redacted>", x, fixed = TRUE)
+  expect_snapshot(
+    {
+      assess_object(big, small)
+      assess_object(small, small)
+      assess_object(small, big)
+    },
+    transform = function(x) gsub(obj_size_diff, "<redacted>", x, fixed = TRUE)
   )
 })
